@@ -2,8 +2,8 @@ def get_provider_info():
   return {
       "package-name": "airflow-provider-fivetran",
       "name": "Fivetran Provider",
-      "description": "An Apache Airflow Provider for Fivetran.",
+      "description": "A Fivetran provider for Apache Airflow.",
       "hook-class-names": ["fivetran_provider.hooks.fivetran.FivetranHook"],
       "extra-links":["fivetran_provider.operators.fivetran.RegistryLink"],
-      "versions": ["0.1.3"]
+      "versions": ["1.0.1"]
   }
